# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["WorkerHealthResponse"]


class WorkerHealthResponse(BaseModel):
    id: Optional[str] = None

    enabled: Optional[bool] = None

    healthy: Optional[bool] = None

    message: Optional[str] = None
